pilas.ejemplos.cargador.VentanaEjemplos

pilas :: ejemplos :: cargador :: VentanaEjemplos :: Class VentanaEjemplos |
[hide private]
[frames] | no frames]

# Class VentanaEjemplos

source code

        object --+
                 |
    ui.Ui_Ejemplos --+
                     |
                    VentanaEjemplos

Instance Methods | [hide private]
setupUi(self, main) | source code
_conectar_signals(self) | source code
_definir_estado_habilitado(self, esta_habilitado) Oculta la barra de progreso y habilita todos los controles. | source code
keyPressEvent(self, event) | source code
_cargar_lista_de_ejemplos(self) | source code
cuando_pulsa_boton_ejecutar(self) | source code
cuando_pulsa_boton_fuente(self) | source code
cuando_pulsa_boton_guardar(self) | source code
cuando_cambia_seleccion(self) | source code
_obtener_item_desde_ruta(self, ruta) | source code
_mostrar_imagen_del_ejemplo(self, ruta) | source code
_mostrar_image_inicial(self) | source code
_mostrar_codigo_del_ejemplo(self, nombre) | source code
_mostrar_codigo_presentacion_inicial(self) | source code
_obtener_codigo_del_ejemplo(self, nombre) | source code
_obtener_item_actual(self) | source code
_ejecutar_ejemplo(self, ruta) | source code
_cuando_termina_la_ejecucion_del_ejemplo(self, estado, process) Vuelve a permitir que se usen todos los botone de la interfaz. | source code
Inherited from `ui.Ui_Ejemplos`: `retranslateUi` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### setupUi(self, main) | source code
Overrides: ui.Ui_Ejemplos.setupUi